"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.deployment.alert_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GetAlertsConfigurationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model id get alerts for"""
    branch_id: builtins.str
    """The branch id get alerts for"""
    environment_id: builtins.str
    """The environment id to save alerts."""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        branch_id: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id", "environment_id", b"environment_id", "model_id", b"model_id"]) -> None: ...

global___GetAlertsConfigurationRequest = GetAlertsConfigurationRequest

class GetAlertsConfigurationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALERTS_FIELD_NUMBER: builtins.int
    @property
    def alerts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.deployment.alert_pb2.AlertRule]:
        """The saved alerts for the model"""
    def __init__(
        self,
        *,
        alerts: collections.abc.Iterable[qwak.deployment.alert_pb2.AlertRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alerts", b"alerts"]) -> None: ...

global___GetAlertsConfigurationResponse = GetAlertsConfigurationResponse

class ApplyAlertsConfigurationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    ALERTS_FIELD_NUMBER: builtins.int
    MODEL_UUID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """Model named ID, which will be used as a routing key for the model"""
    branch_id: builtins.str
    """Branch ID to deploy the model under"""
    @property
    def alerts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.deployment.alert_pb2.AlertRule]:
        """The alerts list for model"""
    model_uuid: builtins.str
    """Model UUID uses to show deployments of model."""
    environment_id: builtins.str
    """Environment to apply alerts"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        branch_id: builtins.str = ...,
        alerts: collections.abc.Iterable[qwak.deployment.alert_pb2.AlertRule] | None = ...,
        model_uuid: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["alerts", b"alerts", "branch_id", b"branch_id", "environment_id", b"environment_id", "model_id", b"model_id", "model_uuid", b"model_uuid"]) -> None: ...

global___ApplyAlertsConfigurationRequest = ApplyAlertsConfigurationRequest

class ApplyAlertsConfigurationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ApplyAlertsConfigurationResponse = ApplyAlertsConfigurationResponse

class GetNotificationChannelsListRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """Environment to get notification for"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___GetNotificationChannelsListRequest = GetNotificationChannelsListRequest

class GetNotificationChannelsListResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATION_CHANNELS_FIELD_NUMBER: builtins.int
    @property
    def notification_channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.deployment.alert_pb2.NotificationChannelSpec]:
        """The Notification Channels exist"""
    def __init__(
        self,
        *,
        notification_channels: collections.abc.Iterable[qwak.deployment.alert_pb2.NotificationChannelSpec] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["notification_channels", b"notification_channels"]) -> None: ...

global___GetNotificationChannelsListResponse = GetNotificationChannelsListResponse

class ApplyNotificationChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATION_CHANNEL_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    @property
    def notification_channel(self) -> qwak.deployment.alert_pb2.NotificationChannel:
        """The Notification channel to add"""
    environment_id: builtins.str
    """Environment to apply notification channels"""
    def __init__(
        self,
        *,
        notification_channel: qwak.deployment.alert_pb2.NotificationChannel | None = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["notification_channel", b"notification_channel"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "notification_channel", b"notification_channel"]) -> None: ...

global___ApplyNotificationChannelRequest = ApplyNotificationChannelRequest

class ApplyNotificationChannelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ApplyNotificationChannelResponse = ApplyNotificationChannelResponse

class DeleteNotificationChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATION_CHANNEL_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    notification_channel_id: builtins.str
    """Notification channel id to delete"""
    environment_id: builtins.str
    """Environment to delete it from"""
    def __init__(
        self,
        *,
        notification_channel_id: builtins.str = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id", "notification_channel_id", b"notification_channel_id"]) -> None: ...

global___DeleteNotificationChannelRequest = DeleteNotificationChannelRequest

class DeleteNotificationChannelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteNotificationChannelResponse = DeleteNotificationChannelResponse

class GetNotificationChannelDetailsListRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    environment_id: builtins.str
    """Environment to get notification details list for"""
    def __init__(
        self,
        *,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_id", b"environment_id"]) -> None: ...

global___GetNotificationChannelDetailsListRequest = GetNotificationChannelDetailsListRequest

class GetNotificationChannelDetailsListResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTIFICATION_CHANNELS_FIELD_NUMBER: builtins.int
    @property
    def notification_channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.deployment.alert_pb2.NotificationChannel]:
        """The channels saved"""
    def __init__(
        self,
        *,
        notification_channels: collections.abc.Iterable[qwak.deployment.alert_pb2.NotificationChannel] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["notification_channels", b"notification_channels"]) -> None: ...

global___GetNotificationChannelDetailsListResponse = GetNotificationChannelDetailsListResponse



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['_qwak_proto',
 '_qwak_proto.qwak.administration.account.v1',
 '_qwak_proto.qwak.administration.authenticated_user.v1',
 '_qwak_proto.qwak.administration.v0.authentication',
 '_qwak_proto.qwak.administration.v0.environments',
 '_qwak_proto.qwak.administration.v0.users',
 '_qwak_proto.qwak.admiral.secret.v0',
 '_qwak_proto.qwak.admiral.user_application_instance.v0',
 '_qwak_proto.qwak.analytics',
 '_qwak_proto.qwak.audience.v1',
 '_qwak_proto.qwak.auto_scaling.v1',
 '_qwak_proto.qwak.automation.v1',
 '_qwak_proto.qwak.batch_job.v1',
 '_qwak_proto.qwak.build.v1',
 '_qwak_proto.qwak.build_settings',
 '_qwak_proto.qwak.builds',
 '_qwak_proto.qwak.data_versioning',
 '_qwak_proto.qwak.deployment',
 '_qwak_proto.qwak.ecosystem.v0',
 '_qwak_proto.qwak.execution.v1',
 '_qwak_proto.qwak.execution.v1.jobs',
 '_qwak_proto.qwak.execution.v1.jobs.reports',
 '_qwak_proto.qwak.execution.v1.state',
 '_qwak_proto.qwak.feature_store.entities',
 '_qwak_proto.qwak.feature_store.features',
 '_qwak_proto.qwak.feature_store.jobs',
 '_qwak_proto.qwak.feature_store.jobs.v1',
 '_qwak_proto.qwak.feature_store.reports',
 '_qwak_proto.qwak.feature_store.serving',
 '_qwak_proto.qwak.feature_store.serving.v1',
 '_qwak_proto.qwak.feature_store.sources',
 '_qwak_proto.qwak.features_operator.v1',
 '_qwak_proto.qwak.features_operator.v2',
 '_qwak_proto.qwak.features_operator.v3',
 '_qwak_proto.qwak.file_versioning',
 '_qwak_proto.qwak.fitness_service',
 '_qwak_proto.qwak.inference.feedback',
 '_qwak_proto.qwak.instance_template',
 '_qwak_proto.qwak.integration',
 '_qwak_proto.qwak.kube_deployment_captain',
 '_qwak_proto.qwak.logging',
 '_qwak_proto.qwak.model_descriptor',
 '_qwak_proto.qwak.models',
 '_qwak_proto.qwak.monitoring.v0',
 '_qwak_proto.qwak.offline.serving.v1',
 '_qwak_proto.qwak.projects',
 '_qwak_proto.qwak.prompt.v1.prompt',
 '_qwak_proto.qwak.secret_service',
 '_qwak_proto.qwak.self_service.account.v0',
 '_qwak_proto.qwak.self_service.user.v1',
 '_qwak_proto.qwak.traffic.v1',
 '_qwak_proto.qwak.user_application.common.v0',
 '_qwak_proto.qwak.user_application.v0',
 '_qwak_proto.qwak.vectors.v1',
 '_qwak_proto.qwak.vectors.v1.collection',
 '_qwak_proto.qwak.vectors.v1.collection.event',
 '_qwak_proto.qwak.workspace',
 'qwak',
 'qwak.automations',
 'qwak.clients',
 'qwak.clients._inner',
 'qwak.clients.administration',
 'qwak.clients.administration.authenticated_user',
 'qwak.clients.administration.authentication',
 'qwak.clients.administration.eco_system',
 'qwak.clients.administration.environment',
 'qwak.clients.administration.self_service',
 'qwak.clients.alert_management',
 'qwak.clients.alerts_registry',
 'qwak.clients.analytics',
 'qwak.clients.audience',
 'qwak.clients.automation_management',
 'qwak.clients.autoscaling',
 'qwak.clients.batch_job_management',
 'qwak.clients.build_management',
 'qwak.clients.build_orchestrator',
 'qwak.clients.data_versioning',
 'qwak.clients.deployment',
 'qwak.clients.feature_store',
 'qwak.clients.file_versioning',
 'qwak.clients.instance_template',
 'qwak.clients.integration_management',
 'qwak.clients.integration_management.openai',
 'qwak.clients.kube_deployment_captain',
 'qwak.clients.logging_client',
 'qwak.clients.model_management',
 'qwak.clients.project',
 'qwak.clients.prompt_manager',
 'qwak.clients.secret_service',
 'qwak.clients.system_secret',
 'qwak.clients.user_application_instance',
 'qwak.clients.vector_store',
 'qwak.clients.workspace_manager',
 'qwak.exceptions',
 'qwak.feature_store',
 'qwak.feature_store._common',
 'qwak.feature_store.data_sources',
 'qwak.feature_store.data_sources.batch',
 'qwak.feature_store.data_sources.batch.filesystem',
 'qwak.feature_store.data_sources.streaming',
 'qwak.feature_store.data_sources.streaming.kafka',
 'qwak.feature_store.entities',
 'qwak.feature_store.execution',
 'qwak.feature_store.feature_sets',
 'qwak.feature_store.feature_sets._utils',
 'qwak.feature_store.feature_sets.transformations',
 'qwak.feature_store.feature_sets.transformations.aggregations',
 'qwak.feature_store.feature_sets.transformations.functions',
 'qwak.feature_store.offline',
 'qwak.feature_store.offline.athena',
 'qwak.feature_store.online',
 'qwak.feature_store.validations',
 'qwak.inner',
 'qwak.inner.build_config',
 'qwak.inner.build_logic',
 'qwak.inner.build_logic.build_loggers',
 'qwak.inner.build_logic.constants',
 'qwak.inner.build_logic.interface',
 'qwak.inner.build_logic.phases',
 'qwak.inner.build_logic.phases.phase_010_fetch_model',
 'qwak.inner.build_logic.phases.phase_010_fetch_model.fetch_strategy_manager',
 'qwak.inner.build_logic.phases.phase_010_fetch_model.fetch_strategy_manager.strategy',
 'qwak.inner.build_logic.phases.phase_010_fetch_model.fetch_strategy_manager.strategy.folder',
 'qwak.inner.build_logic.phases.phase_010_fetch_model.fetch_strategy_manager.strategy.git',
 'qwak.inner.build_logic.phases.phase_010_fetch_model.fetch_strategy_manager.strategy.zip',
 'qwak.inner.build_logic.phases.phase_020_remote_register_qwak_build',
 'qwak.inner.build_logic.run_handlers',
 'qwak.inner.build_logic.tools',
 'qwak.inner.di_configuration',
 'qwak.inner.instance_template',
 'qwak.inner.runtime_di',
 'qwak.inner.tool',
 'qwak.inner.tool.grpc',
 'qwak.inner.tool.run_config',
 'qwak.llmops',
 'qwak.llmops.generation',
 'qwak.llmops.generation.chat',
 'qwak.llmops.generation.chat.openai.types',
 'qwak.llmops.generation.chat.openai.types.chat',
 'qwak.llmops.generation.chat.openai.types.shared',
 'qwak.llmops.generation.chat.openai.types.shared_params',
 'qwak.llmops.model',
 'qwak.llmops.prompt',
 'qwak.llmops.prompt.chat',
 'qwak.llmops.provider',
 'qwak.llmops.provider.openai',
 'qwak.model',
 'qwak.model.adapters',
 'qwak.model.adapters.input_adapters',
 'qwak.model.adapters.output_adapters',
 'qwak.model.decorators',
 'qwak.model.decorators.impl',
 'qwak.model.tools',
 'qwak.model.tools.adapters',
 'qwak.model.tools.adapters.input_adapters',
 'qwak.model.tools.adapters.output_adapters',
 'qwak.model.utils',
 'qwak.model_loggers',
 'qwak.qwak_client',
 'qwak.qwak_client.batch_jobs',
 'qwak.qwak_client.build_api_helpers',
 'qwak.qwak_client.builds',
 'qwak.qwak_client.builds.filters',
 'qwak.qwak_client.data_versioning',
 'qwak.qwak_client.deployments',
 'qwak.qwak_client.file_versioning',
 'qwak.qwak_client.models',
 'qwak.qwak_client.projects',
 'qwak.testing',
 'qwak.tools',
 'qwak.tools.logger',
 'qwak.utils',
 'qwak.vector_store',
 'qwak.vector_store.utils',
 'qwak_services_mock',
 'qwak_services_mock.mocks',
 'qwak_services_mock.mocks.utils',
 'qwak_services_mock.utils']

package_data = \
{'': ['*'], 'qwak.llmops.generation.chat': ['openai/*']}

install_requires = \
['PyYAML',
 'chevron==0.14.0',
 'dacite==1.8.1',
 'dependency-injector>=4.0',
 'grpcio>=1.57.0',
 'joblib>=1.3.2,<2.0.0',
 'marshmallow-dataclass>=8.5.8,<9.0.0',
 'python-jose',
 'python-json-logger>=2.0.2',
 'requests',
 'retrying==1.3.4',
 'typeguard>=2,<3']

extras_require = \
{':extra == "feature-store"': ['cloudpickle==2.2.1'],
 ':python_full_version >= "3.7.1" and python_version < "3.10"': ['protobuf>=3.10,<4'],
 ':python_version >= "3.10"': ['protobuf>=4.21.6'],
 'feature-store': ['pyarrow>=6.0.0', 'pyathena>=2.2.0,!=2.18.0']}

setup_kwargs = {
    'name': 'qwak-core',
    'version': '0.4.49',
    'description': 'Qwak Core contains the necessary objects and communication tools for using the Qwak Platform',
    'long_description': '# Qwak Core\n\nQwak is an end-to-end production ML platform designed to allow data scientists to build, deploy, and monitor their models in production with minimal engineering friction.\nQwak Core contains all the objects and tools necessary to use the Qwak Platform\n',
    'author': 'Qwak',
    'author_email': 'info@qwak.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.7.1,<3.12',
}


setup(**setup_kwargs)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.feature_store.features.feature_set_pb2
import qwak.feature_store.sources.data_source_pb2
import qwak.features_operator.v3.features_operator_pb2
import sys
import typing

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ValidateDataSourceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_SPEC_FIELD_NUMBER: builtins.int
    NUM_SAMPLES_FIELD_NUMBER: builtins.int
    VALIDATION_OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def data_source_spec(self) -> qwak.feature_store.sources.data_source_pb2.DataSourceSpec:
        """Data source spec to validate"""
    num_samples: builtins.int
    """Number of samples to return from the validation"""
    @property
    def validation_options(self) -> global___DataSourceValidationOptions: ...
    def __init__(
        self,
        *,
        data_source_spec: qwak.feature_store.sources.data_source_pb2.DataSourceSpec | None = ...,
        num_samples: builtins.int = ...,
        validation_options: global___DataSourceValidationOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_source_spec", b"data_source_spec", "optional_validation_options", b"optional_validation_options", "validation_options", b"validation_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source_spec", b"data_source_spec", "num_samples", b"num_samples", "optional_validation_options", b"optional_validation_options", "validation_options", b"validation_options"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_validation_options", b"optional_validation_options"]) -> typing_extensions.Literal["validation_options"] | None: ...

global___ValidateDataSourceRequest = ValidateDataSourceRequest

class ValidateFeatureSetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURE_SET_SPEC_FIELD_NUMBER: builtins.int
    ZIP_PATH_FIELD_NUMBER: builtins.int
    NUM_SAMPLES_FIELD_NUMBER: builtins.int
    VALIDATION_OPTIONS_FIELD_NUMBER: builtins.int
    @property
    def feature_set_spec(self) -> qwak.feature_store.features.feature_set_pb2.FeatureSetSpec:
        """Featureset spec to validate"""
    zip_path: builtins.str
    """Dependencies zip file path"""
    num_samples: builtins.int
    """Number of samples to return from the validation"""
    @property
    def validation_options(self) -> global___FeatureSetValidationOptions: ...
    def __init__(
        self,
        *,
        feature_set_spec: qwak.feature_store.features.feature_set_pb2.FeatureSetSpec | None = ...,
        zip_path: builtins.str = ...,
        num_samples: builtins.int = ...,
        validation_options: global___FeatureSetValidationOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["feature_set_spec", b"feature_set_spec", "optional_validation_options", b"optional_validation_options", "validation_options", b"validation_options"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_spec", b"feature_set_spec", "num_samples", b"num_samples", "optional_validation_options", b"optional_validation_options", "validation_options", b"validation_options", "zip_path", b"zip_path"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_validation_options", b"optional_validation_options"]) -> typing_extensions.Literal["validation_options"] | None: ...

global___ValidateFeatureSetRequest = ValidateFeatureSetRequest

class ValidationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """User request token"""
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_id", b"request_id"]) -> None: ...

global___ValidationResponse = ValidationResponse

class GetValidationResultRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """User request token"""
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_id", b"request_id"]) -> None: ...

global___GetValidationResultRequest = GetValidationResultRequest

class GetValidationResultResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_RESPONSE_FIELD_NUMBER: builtins.int
    FAILURE_RESPONSE_FIELD_NUMBER: builtins.int
    NOT_READY_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def success_response(self) -> qwak.features_operator.v3.features_operator_pb2.ValidationSuccessResponse: ...
    @property
    def failure_response(self) -> qwak.features_operator.v3.features_operator_pb2.ValidationFailureResponse: ...
    @property
    def not_ready_response(self) -> qwak.features_operator.v3.features_operator_pb2.ValidationNotReadyResponse: ...
    def __init__(
        self,
        *,
        success_response: qwak.features_operator.v3.features_operator_pb2.ValidationSuccessResponse | None = ...,
        failure_response: qwak.features_operator.v3.features_operator_pb2.ValidationFailureResponse | None = ...,
        not_ready_response: qwak.features_operator.v3.features_operator_pb2.ValidationNotReadyResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["failure_response", b"failure_response", "not_ready_response", b"not_ready_response", "success_response", b"success_response", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_response", b"failure_response", "not_ready_response", b"not_ready_response", "success_response", b"success_response", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["success_response", "failure_response", "not_ready_response"] | None: ...

global___GetValidationResultResponse = GetValidationResultResponse

class CancelValidationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_id", b"request_id"]) -> None: ...

global___CancelValidationRequest = CancelValidationRequest

class CancelValidationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CancelValidationResponse = CancelValidationResponse

class FeatureSetValidationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_SOURCE_LIMIT_FIELD_NUMBER: builtins.int
    VALIDATION_TIME_RANGE_FIELD_NUMBER: builtins.int
    data_source_limit: builtins.int
    @property
    def validation_time_range(self) -> global___ValidationTimeRange: ...
    def __init__(
        self,
        *,
        data_source_limit: builtins.int = ...,
        validation_time_range: global___ValidationTimeRange | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_source_limit", b"data_source_limit", "optional_data_source_limit", b"optional_data_source_limit", "optional_validation_time_range", b"optional_validation_time_range", "validation_time_range", b"validation_time_range"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_source_limit", b"data_source_limit", "optional_data_source_limit", b"optional_data_source_limit", "optional_validation_time_range", b"optional_validation_time_range", "validation_time_range", b"validation_time_range"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_data_source_limit", b"optional_data_source_limit"]) -> typing_extensions.Literal["data_source_limit"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_validation_time_range", b"optional_validation_time_range"]) -> typing_extensions.Literal["validation_time_range"] | None: ...

global___FeatureSetValidationOptions = FeatureSetValidationOptions

class DataSourceValidationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATION_TIME_RANGE_FIELD_NUMBER: builtins.int
    @property
    def validation_time_range(self) -> global___ValidationTimeRange: ...
    def __init__(
        self,
        *,
        validation_time_range: global___ValidationTimeRange | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["optional_validation_time_range", b"optional_validation_time_range", "validation_time_range", b"validation_time_range"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["optional_validation_time_range", b"optional_validation_time_range", "validation_time_range", b"validation_time_range"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_validation_time_range", b"optional_validation_time_range"]) -> typing_extensions.Literal["validation_time_range"] | None: ...

global___DataSourceValidationOptions = DataSourceValidationOptions

class ValidationTimeRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOWER_TIME_BOUND_FIELD_NUMBER: builtins.int
    UPPER_TIME_BOUND_FIELD_NUMBER: builtins.int
    @property
    def lower_time_bound(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def upper_time_bound(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        lower_time_bound: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        upper_time_bound: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["lower_time_bound", b"lower_time_bound", "optional_lower_time_bound", b"optional_lower_time_bound", "optional_upper_time_bound", b"optional_upper_time_bound", "upper_time_bound", b"upper_time_bound"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["lower_time_bound", b"lower_time_bound", "optional_lower_time_bound", b"optional_lower_time_bound", "optional_upper_time_bound", b"optional_upper_time_bound", "upper_time_bound", b"upper_time_bound"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_lower_time_bound", b"optional_lower_time_bound"]) -> typing_extensions.Literal["lower_time_bound"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["optional_upper_time_bound", b"optional_upper_time_bound"]) -> typing_extensions.Literal["upper_time_bound"] | None: ...

global___ValidationTimeRange = ValidationTimeRange



import inspect as inspect
from typing import Callable

from qwak.exceptions import QwakException
from qwak.feature_store.feature_sets.transformations.functions.schema import Schema
from qwak.tools.logger import get_qwak_logger, setup_qwak_logger

logger = get_qwak_logger()
setup_qwak_logger()


def _get_schema_string(user_function: Callable, schema: Schema) -> str:
    import pandas as pd

    input_signature = inspect.signature(user_function)
    return_annotation = input_signature.return_annotation
    if return_annotation is inspect._empty:
        raise QwakException(
            f"return type annotation missing for {user_function.__name__}"
        )

    if return_annotation is pd.DataFrame:
        # return type is a Pandas DataFrame - all cols must be named
        if any([c for c in schema.columns if not c.name]):
            raise QwakException(
                f"pandas UDFs that return pd.DataFrame must have named columns."
                f" Please specify the name in the schema constructor"
                f" the Schema constructor? {user_function.__name__}"
            )
        return schema.to_ddl()

    if return_annotation is pd.Series:
        # return type is a series (meaning the UDF returns a single colum)
        if len(schema.columns) != 1:
            raise QwakException(
                f"Exactly 1 return type must be set for"
                f" a pandas udf returning pd.Series,"
                f" Function {user_function.__name__} returning pd.Series must return exactly 1 return type."
            )
        return_col = schema.columns[0]
        if return_col.name:
            logger.warning(
                f"return column name specified for {user_function.__name__},"
                f" however it will be disregarded as it returns pd.Series"
            )
        return return_col.type.to_ddl()

    raise QwakException(
        f"missing or unrecognized type annotation for {user_function.__name__}"
    )


def qwak_pandas_udf(output_schema: Schema) -> Callable:
    if not isinstance(output_schema, Schema):
        raise QwakException("Wrong schema type set for qwak_pandas_udf")

    def _qwak_pandas_udf(user_function: Callable) -> Callable:
        setattr(
            user_function,
            "_schema",
            _get_schema_string(user_function=user_function, schema=output_schema),
        )
        return user_function

    return _qwak_pandas_udf



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DeploymentUpdateRequestStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeploymentUpdateRequestStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeploymentUpdateRequestStatus.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEPLOYMENT_UPDATE_REQUEST_INVALID_STATUS: _DeploymentUpdateRequestStatus.ValueType  # 0
    """Invalid proto status"""
    INVALID_DEPLOYMENT_UPDATE_REQUEST: _DeploymentUpdateRequestStatus.ValueType  # 1
    """Invalid deployment update request status"""
    INITIATING_DEPLOYMENT_UPDATE_REQUEST: _DeploymentUpdateRequestStatus.ValueType  # 2
    """Deployment update request is initiating"""
    FAILED_INITIATING_DEPLOYMENT_UPDATE_REQUEST: _DeploymentUpdateRequestStatus.ValueType  # 3
    """Failed to initiate a deployment update request process"""
    PENDING_DEPLOYMENT_UPDATE_REQUEST: _DeploymentUpdateRequestStatus.ValueType  # 4
    """Deployment update request is in progress"""
    SUCCESSFUL_DEPLOYMENT_UPDATE_REQUEST: _DeploymentUpdateRequestStatus.ValueType  # 5
    """Deployment update request has finished successfully"""

class DeploymentUpdateRequestStatus(_DeploymentUpdateRequestStatus, metaclass=_DeploymentUpdateRequestStatusEnumTypeWrapper): ...

DEPLOYMENT_UPDATE_REQUEST_INVALID_STATUS: DeploymentUpdateRequestStatus.ValueType  # 0
"""Invalid proto status"""
INVALID_DEPLOYMENT_UPDATE_REQUEST: DeploymentUpdateRequestStatus.ValueType  # 1
"""Invalid deployment update request status"""
INITIATING_DEPLOYMENT_UPDATE_REQUEST: DeploymentUpdateRequestStatus.ValueType  # 2
"""Deployment update request is initiating"""
FAILED_INITIATING_DEPLOYMENT_UPDATE_REQUEST: DeploymentUpdateRequestStatus.ValueType  # 3
"""Failed to initiate a deployment update request process"""
PENDING_DEPLOYMENT_UPDATE_REQUEST: DeploymentUpdateRequestStatus.ValueType  # 4
"""Deployment update request is in progress"""
SUCCESSFUL_DEPLOYMENT_UPDATE_REQUEST: DeploymentUpdateRequestStatus.ValueType  # 5
"""Deployment update request has finished successfully"""
global___DeploymentUpdateRequestStatus = DeploymentUpdateRequestStatus

class _DeploymentStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeploymentStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeploymentStatus.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEPLOYMENT_INVALID_STATUS: _DeploymentStatus.ValueType  # 0
    """Invalid proto status"""
    DEPLOYMENT_RUNNING: _DeploymentStatus.ValueType  # 1
    """DEPLOYMENT IS IN RUNNING STATE"""
    DEPLOYMENT_UPDATE_IN_PROGRESS: _DeploymentStatus.ValueType  # 2
    """DEPLOYMENT UPDATE REQUEST IS IN PROGRESS"""
    DEPLOYMENT_UNDEPLOYED: _DeploymentStatus.ValueType  # 3
    """DEPLOYMENT WAS DELETED"""
    DEPLOYMENT_FAILED: _DeploymentStatus.ValueType  # 4
    """DEPLOYMENT IS FAILING"""

class DeploymentStatus(_DeploymentStatus, metaclass=_DeploymentStatusEnumTypeWrapper): ...

DEPLOYMENT_INVALID_STATUS: DeploymentStatus.ValueType  # 0
"""Invalid proto status"""
DEPLOYMENT_RUNNING: DeploymentStatus.ValueType  # 1
"""DEPLOYMENT IS IN RUNNING STATE"""
DEPLOYMENT_UPDATE_IN_PROGRESS: DeploymentStatus.ValueType  # 2
"""DEPLOYMENT UPDATE REQUEST IS IN PROGRESS"""
DEPLOYMENT_UNDEPLOYED: DeploymentStatus.ValueType  # 3
"""DEPLOYMENT WAS DELETED"""
DEPLOYMENT_FAILED: DeploymentStatus.ValueType  # 4
"""DEPLOYMENT IS FAILING"""
global___DeploymentStatus = DeploymentStatus

class _DeploymentFailureReasonCode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DeploymentFailureReasonCodeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DeploymentFailureReasonCode.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID_FAILURE_CODE: _DeploymentFailureReasonCode.ValueType  # 0
    """Invalid failure reason"""
    UNKNOWN_REASON: _DeploymentFailureReasonCode.ValueType  # 1
    """Unknown failure reason"""
    NO_REPLICA_SETS_PODS_FOUND: _DeploymentFailureReasonCode.ValueType  # 2
    """No replica sets pods found reason"""
    CONTAINER_NOT_FOUND: _DeploymentFailureReasonCode.ValueType  # 3
    """Container not found reason"""
    UNSCHEDULABLE: _DeploymentFailureReasonCode.ValueType  # 4
    """Unschedulable reason"""
    DOCKER_IMAGE_NOT_FOUND: _DeploymentFailureReasonCode.ValueType  # 5
    """Docker image not found reason"""
    MEMORY_LIMIT_EXCEEDED: _DeploymentFailureReasonCode.ValueType  # 6
    """Memory limit exceeded reason"""
    CRASH_LOOP: _DeploymentFailureReasonCode.ValueType  # 7
    """Crash loop reason"""
    CONTAINER_FAIL_TO_LOAD_FOR_UNKNOWN_REASON: _DeploymentFailureReasonCode.ValueType  # 8
    """Container fail to load for unknown reason"""

class DeploymentFailureReasonCode(_DeploymentFailureReasonCode, metaclass=_DeploymentFailureReasonCodeEnumTypeWrapper): ...

INVALID_FAILURE_CODE: DeploymentFailureReasonCode.ValueType  # 0
"""Invalid failure reason"""
UNKNOWN_REASON: DeploymentFailureReasonCode.ValueType  # 1
"""Unknown failure reason"""
NO_REPLICA_SETS_PODS_FOUND: DeploymentFailureReasonCode.ValueType  # 2
"""No replica sets pods found reason"""
CONTAINER_NOT_FOUND: DeploymentFailureReasonCode.ValueType  # 3
"""Container not found reason"""
UNSCHEDULABLE: DeploymentFailureReasonCode.ValueType  # 4
"""Unschedulable reason"""
DOCKER_IMAGE_NOT_FOUND: DeploymentFailureReasonCode.ValueType  # 5
"""Docker image not found reason"""
MEMORY_LIMIT_EXCEEDED: DeploymentFailureReasonCode.ValueType  # 6
"""Memory limit exceeded reason"""
CRASH_LOOP: DeploymentFailureReasonCode.ValueType  # 7
"""Crash loop reason"""
CONTAINER_FAIL_TO_LOAD_FOR_UNKNOWN_REASON: DeploymentFailureReasonCode.ValueType  # 8
"""Container fail to load for unknown reason"""
global___DeploymentFailureReasonCode = DeploymentFailureReasonCode

class DeploymentUpdateRequestState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVALID_REQUEST_TYPE_FIELD_NUMBER: builtins.int
    UPDATE_REQUEST_TYPE_FIELD_NUMBER: builtins.int
    UNDEPLOY_REQUEST_TYPE_FIELD_NUMBER: builtins.int
    DEPLOYMENT_UPDATE_REQUEST_STATUS_FIELD_NUMBER: builtins.int
    @property
    def invalid_request_type(self) -> global___DeploymentInvalidRequestType: ...
    @property
    def update_request_type(self) -> global___DeploymentUpdateRequestType: ...
    @property
    def undeploy_request_type(self) -> global___DeploymentUndeployRequestType: ...
    deployment_update_request_status: global___DeploymentUpdateRequestStatus.ValueType
    def __init__(
        self,
        *,
        invalid_request_type: global___DeploymentInvalidRequestType | None = ...,
        update_request_type: global___DeploymentUpdateRequestType | None = ...,
        undeploy_request_type: global___DeploymentUndeployRequestType | None = ...,
        deployment_update_request_status: global___DeploymentUpdateRequestStatus.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["invalid_request_type", b"invalid_request_type", "type", b"type", "undeploy_request_type", b"undeploy_request_type", "update_request_type", b"update_request_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_update_request_status", b"deployment_update_request_status", "invalid_request_type", b"invalid_request_type", "type", b"type", "undeploy_request_type", b"undeploy_request_type", "update_request_type", b"update_request_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["invalid_request_type", "update_request_type", "undeploy_request_type"] | None: ...

global___DeploymentUpdateRequestState = DeploymentUpdateRequestState

class DeploymentInvalidRequestType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeploymentInvalidRequestType = DeploymentInvalidRequestType

class DeploymentUpdateRequestType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeploymentUpdateRequestType = DeploymentUpdateRequestType

class DeploymentUndeployRequestType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeploymentUndeployRequestType = DeploymentUndeployRequestType

class DeploymentState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTRACTOR_IDENTIFIER_FIELD_NUMBER: builtins.int
    STATUS_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def extractor_identifier(self) -> global___ExtractorDeploymentIdentifier: ...
    @property
    def status_details(self) -> global___DeploymentStatusDetails:
        """Deployment status details of the current state"""
    def __init__(
        self,
        *,
        extractor_identifier: global___ExtractorDeploymentIdentifier | None = ...,
        status_details: global___DeploymentStatusDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["extractor_identifier", b"extractor_identifier", "identifier_type", b"identifier_type", "status_details", b"status_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["extractor_identifier", b"extractor_identifier", "identifier_type", b"identifier_type", "status_details", b"status_details"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["identifier_type", b"identifier_type"]) -> typing_extensions.Literal["extractor_identifier"] | None: ...

global___DeploymentState = DeploymentState

class ExtractorDeploymentIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTRACTOR_DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    EXTRACTOR_ID_FIELD_NUMBER: builtins.int
    FEATURESET_ID_FIELD_NUMBER: builtins.int
    extractor_deployment_id: builtins.str
    """The ID of the current deployment"""
    extractor_id: builtins.str
    """The ID of the extractor to deploy"""
    featureset_id: builtins.str
    """The ID of the featureset to which the extractor belongs"""
    def __init__(
        self,
        *,
        extractor_deployment_id: builtins.str = ...,
        extractor_id: builtins.str = ...,
        featureset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["extractor_deployment_id", b"extractor_deployment_id", "extractor_id", b"extractor_id", "featureset_id", b"featureset_id"]) -> None: ...

global___ExtractorDeploymentIdentifier = ExtractorDeploymentIdentifier

class DeploymentStatusDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPDATE_IN_PROGRESS_STATUS_DETAILS_FIELD_NUMBER: builtins.int
    RUNNING_STATUS_DETAILS_FIELD_NUMBER: builtins.int
    FAILED_STATUS_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def update_in_progress_status_details(self) -> global___UpdateInProgressStatusDetails:
        """Detailed information about the update in progress status"""
    @property
    def running_status_details(self) -> global___RunningStatusDetails:
        """Detailed information about the active running deployment stats"""
    @property
    def failed_status_details(self) -> global___FailedStatusDetails:
        """Detailed information about the failed deployment"""
    def __init__(
        self,
        *,
        update_in_progress_status_details: global___UpdateInProgressStatusDetails | None = ...,
        running_status_details: global___RunningStatusDetails | None = ...,
        failed_status_details: global___FailedStatusDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["failed_status_details", b"failed_status_details", "running_status_details", b"running_status_details", "status_details", b"status_details", "update_in_progress_status_details", b"update_in_progress_status_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["failed_status_details", b"failed_status_details", "running_status_details", b"running_status_details", "status_details", b"status_details", "update_in_progress_status_details", b"update_in_progress_status_details"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["status_details", b"status_details"]) -> typing_extensions.Literal["update_in_progress_status_details", "running_status_details", "failed_status_details"] | None: ...

global___DeploymentStatusDetails = DeploymentStatusDetails

class UpdateInProgressStatusDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OLD_INSTANCE_FIELD_NUMBER: builtins.int
    NEW_INSTANCE_FIELD_NUMBER: builtins.int
    @property
    def old_instance(self) -> global___InstanceDetails:
        """Detailed information about the old instance"""
    @property
    def new_instance(self) -> global___InstanceDetails:
        """Detailed information about the new instance"""
    def __init__(
        self,
        *,
        old_instance: global___InstanceDetails | None = ...,
        new_instance: global___InstanceDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["new_instance", b"new_instance", "old_instance", b"old_instance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["new_instance", b"new_instance", "old_instance", b"old_instance"]) -> None: ...

global___UpdateInProgressStatusDetails = UpdateInProgressStatusDetails

class RunningStatusDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RUNNING_INSTANCE_FIELD_NUMBER: builtins.int
    @property
    def running_instance(self) -> global___InstanceDetails:
        """Detailed information about the running instance"""
    def __init__(
        self,
        *,
        running_instance: global___InstanceDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["running_instance", b"running_instance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["running_instance", b"running_instance"]) -> None: ...

global___RunningStatusDetails = RunningStatusDetails

class FailedStatusDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAILURE_DETAILS_FIELD_NUMBER: builtins.int
    OLD_INSTANCE_FIELD_NUMBER: builtins.int
    FAILED_INSTANCE_FIELD_NUMBER: builtins.int
    @property
    def failure_details(self) -> global___FailureDetails:
        """Detailed information about the failure status"""
    @property
    def old_instance(self) -> global___InstanceDetails:
        """Detailed information about the previous deployment instance"""
    @property
    def failed_instance(self) -> global___InstanceDetails:
        """Detailed information about the failed instance"""
    def __init__(
        self,
        *,
        failure_details: global___FailureDetails | None = ...,
        old_instance: global___InstanceDetails | None = ...,
        failed_instance: global___InstanceDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["failed_instance", b"failed_instance", "failure_details", b"failure_details", "old_instance", b"old_instance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["failed_instance", b"failed_instance", "failure_details", b"failure_details", "old_instance", b"old_instance"]) -> None: ...

global___FailedStatusDetails = FailedStatusDetails

class FailureDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOYMENT_FAILURE_REASON_CODE_FIELD_NUMBER: builtins.int
    FAILURE_REASON_DETAILS_FIELD_NUMBER: builtins.int
    deployment_failure_reason_code: global___DeploymentFailureReasonCode.ValueType
    """The failure reason - Machine-readable"""
    failure_reason_details: builtins.str
    """The message describing the reason"""
    def __init__(
        self,
        *,
        deployment_failure_reason_code: global___DeploymentFailureReasonCode.ValueType = ...,
        failure_reason_details: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_failure_reason_code", b"deployment_failure_reason_code", "failure_reason_details", b"failure_reason_details"]) -> None: ...

global___FailureDetails = FailureDetails

class InstanceDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTRACTOR_IDENTIFIER_FIELD_NUMBER: builtins.int
    AVAILABLE_REPLICAS_FIELD_NUMBER: builtins.int
    @property
    def extractor_identifier(self) -> global___ExtractorInstanceIdentifier: ...
    available_replicas: builtins.int
    """Available replicas"""
    def __init__(
        self,
        *,
        extractor_identifier: global___ExtractorInstanceIdentifier | None = ...,
        available_replicas: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["extractor_identifier", b"extractor_identifier", "identifier_type", b"identifier_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["available_replicas", b"available_replicas", "extractor_identifier", b"extractor_identifier", "identifier_type", b"identifier_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["identifier_type", b"identifier_type"]) -> typing_extensions.Literal["extractor_identifier"] | None: ...

global___InstanceDetails = InstanceDetails

class ExtractorInstanceIdentifier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTRACTOR_DEPLOYMENT_UPDATE_REQUEST_ID_FIELD_NUMBER: builtins.int
    extractor_deployment_update_request_id: builtins.str
    """The ID of the current deployment"""
    def __init__(
        self,
        *,
        extractor_deployment_update_request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["extractor_deployment_update_request_id", b"extractor_deployment_update_request_id"]) -> None: ...

global___ExtractorInstanceIdentifier = ExtractorInstanceIdentifier
